@@ -1,12 +1,13 @@
 import os
+
 import click
+from prettytable import PrettyTable
 
 from cnvrgv2.cli.utils import messages
-from cnvrgv2.config import error_messages
 from cnvrgv2.cli.utils.decorators import prepare_command
-from cnvrgv2.config import Config, CONFIG_FOLDER_NAME
+from cnvrgv2.config import CONFIG_FOLDER_NAME, Config
+from cnvrgv2.config import error_messages
 from cnvrgv2.utils.storage_utils import cnvrgignore_exists, create_cnvrgignore
-from prettytable import PrettyTable
 
 
 @click.group(name='project')
@@ -175,13 +176,16 @@ def link_git(cnvrg, logger, name, soft):
 @project_group.command()
 @click.option('-j', '--job-slug', default=None, help=messages.PROJECT_JOB_SLUG_HELP_NAME)
 @click.option('-g', '--git-diff', is_flag=True, default=None, help=messages.DATA_UPLOAD_HELP_GIT_DIFF)
+@click.option('-m', '--message', default="", help=messages.DATA_COMMIT_MESSAGE)
+@click.option('-o', '--output-dir', default=None, help=messages.SYNC_OUTPUT_DIR)
 @prepare_command()
-def sync(project, logger, job_slug=None, git_diff=None):
+def sync(project, logger, message, job_slug=None, git_diff=None, output_dir=None):
     """
     Sync local project to remote
     """
     logger.log_and_echo('Syncing...')
-    project.sync(job_slug=job_slug, git_diff=git_diff, progress_bar_enabled=True)
+    project.sync(job_slug=job_slug, git_diff=git_diff, progress_bar_enabled=True, message=message,
+                 output_dir=output_dir)
     logger.log_and_echo(messages.PROJECT_SYNC_SUCCESS.format(project.slug))
 
 
@@ -214,4 +218,5 @@ def rm(cnvrg, logger, name, files, message):
     project = cnvrg.projects.get(name)
     removed_files_count = project.remove_files(paths=file_paths, message=message, progress_bar_enabled=True)
     str_count = str(removed_files_count)
-    logger.log_and_echo(f"{str_count} File{'s'[:removed_files_count^1]} removed.")
+    pluralize = "File{}".format('s'[:removed_files_count ^ 1])  # Pluralizes the word (File/Files)
+    logger.log_and_echo("{} {} removed.".format(str_count, pluralize))
