@@ -1,5 +1,6 @@
 # COMMON
 CLI_UNEXPECTED_ERROR = "Unexpected error while executing command. details: {0}"
+OUTPUT_DIR_LOCATION = "the location of the output directory"
 
 # LOGIN
 LOGIN_PROMPT_DOMAIN = "Please enter your cnvrg domain"
@@ -25,6 +26,9 @@ DATA_UPLOAD_HELP_GIT_DIFF = "From the list of files, upload those who returned f
 DATA_PROMPT_COMMIT = "Please enter sha1 to clone"
 DATA_PROMPT_CACHE = "Please enter sha1 to cache"
 DATA_DOWNLOAD_ERROR = "Unexpected error while executing command"
+SYNC_OUTPUT_DIR = "The directory that will be synced inside the project"
+CLONE_NUMBER_OF_THREADS = "Number of threads that will be used to preform the clone"
+QUERY_SLUG = "Query slug"
 
 
 # DATASET
@@ -111,13 +115,24 @@ COMMIT_SHA1_MESSAGE = "Commit sha1: {0}"
 LIBRARY_PROMPT_CLONE = "Please enter library name to clone"
 LIBRARY_VERSION_PROMPT_CLONE = "Please enter library version name to clone (default = \"latest\")"
 LIBRARY_CLONE_SKIP = "Library {0} is already cloned, skipping action"
-LIBRARY_CLONE_SUCCESS = "Successfully cloned project: {0}"
+LIBRARY_CLONE_SUCCESS = "Successfully cloned library: {0}"
+
+# MEMBERS
+MEMBER_ADDED_SUCCESS = "{0} was added successfully with role {1}"
+MEMBER_UPDATED_SUCCESS = "{0} was updated successfully to role {1}"
+MEMBER_ENTER_EMAIL = "Please enter a valid user email"
+MEMBER_HELP_EMAIL = "A valid email of exists user"
+MEMBER_ENTER_ROLE = "Please enter a valid role [admin, manager, member, reviewer]"
+MEMBER_HELP_ROLE = "A role for the user, must be one of the following: admin, manager, member, reviewer"
+MEMBER_REMOVED_SUCCESS = "{0} was removed successfully"
 
 
 # EXPERIMENT
 EXPERIMENT_PROMPT_TITLE = "Please enter a title for the experiment"
 EXPERIMENT_PROMPT_COMMIT = "Please enter commit to merge"
+EXPERIMENT_ARTIFACTS_PROMPT_COMMIT = "Please enter commit"
 EXPERIMENT_HELP_COMMIT = "Commit sha1 to merge"
+EXPERIMENT_ARTIFACTS_HELP_COMMIT = "Commit sha1 of artifacts"
 EXPERIMENT_HELP_TITLE = "Name of the experiment"
 EXPERIMENT_HELP_TEMPLATES = "Comma separated list of template names"
 EXPERIMENT_HELP_LOCAL = "Boolean. Run the experiment locally"
@@ -134,6 +149,11 @@ EXPERIMENT_CREATE_SUCCESS = "Experiment {0} created successfully. \r\nExperiment
 EXPERIMENT_MERGE_SUCCESS = "Commit successfully merged to master"
 EXPERIMENT_GIT_ERROR_MESSAGE = "Cannot merge commits for git projects"
 EXPERIMENT_DOES_NOT_EXIST = "Couldn't find experiment. Try with env variables or passing --slug"
+EXPERIMENT_LOG_ARTIFACTS_SUCCESS = "Successfully logged artifacts"
+EXPERIMENT_LOG_IMAGES_SUCCESS = "Successfully logged images"
+EXPERIMENT_PULL_ARTIFACTS_SUCCESS = "Successfully pulled artifacts"
+EXPERIMENT_HELP_WORK_DIR = "Working Dir to upload files to"
+
 
 # LOGS
 LOG_START_COMMAND = "Starting command {0}. Options: {1}"
@@ -155,8 +175,56 @@ SSH_READY = "\r\nSsh session is ready to receive connections.\r\n" \
             "username: {1}\r\n"\
             "password: {2}"
 
+# WORKSPACE
+WORKSPACE_DOES_NOT_EXIST = "Workspace was not found, check env or pass slug"
+WORKSPACE_SLUG = "Slug of the workspace"
+
+# ENDPOINT
+Endpoint_DOES_NOT_EXIST = "Endpoint was not found, check env or pass slug"
+ENDPOINT_SLUG = "Slug of the endpoint"
+ENDPOINT_PROMPT_METRIC_NAME = "Please enter the metric name"
+ENDPOINT_PROMPT_METRIC_X = "Please enter the metric x value"
+ENDPOINT_PROMPT_METRIC_Y = "Please enter the metric y value"
+ENDPOINT_METRIC_NAME = "The metric name"
+ENDPOINT_METRIC_X = "The metric x value"
+ENDPOINT_METRIC_Y = "The metric y value"
+
 # CONFIG
 CONFIG_HELP_CHECK_CERTIFICATE = "{0} ssl validation on https requests"
 CONFIG_UPDATE_SUCCESS = "Config updated successfully"
 CONFIG_HELP_ORGANIZTION = "Name of organization to switch to"
 CONFIG_NO_ARGS_LOG = "No arguments sent. Showing help message instead"
+
+# IMAGE
+IMAGE_HELP_TAG = "Image tag"
+IMAGE_HELP_SLUG = "Image slug"
+IMAGE_HELP_NAME = "Image repository name"
+IMAGE_HELP_LOGO = "Image logo"
+IMAGE_HELP_CUSTOM = "Is custom image (requires dockerfile)"
+IMAGE_HELP_README = "Readme path for the image"
+IMAGE_HELP_REGISTRY = "Image registry"
+IMAGE_HELP_DOCKERFILE = "Dockerfile path to build a custom image"
+
+IMAGE_PROMPT_TAG = "Please enter image tag"
+IMAGE_PROMPT_SLUG = "Please enter image slug"
+IMAGE_PROMPT_NAME = "Please enter image name (repository)"
+IMAGE_PROMPT_LOGO = "Please enter image logo"
+IMAGE_PROMPT_REGISTRY = "Please enter image registry"
+
+IMAGE_INVALID_README = "Readme path is invalid"
+IMAGE_INVALID_DOCKERFILE = "Dockerfile path is invalid"
+
+IMAGE_CREATE_SUCCESS = "Successfully created image {0}"
+
+# REGISTRY
+REGISTRY_HELP_URL = "Registry url"
+REGISTRY_HELP_TYPE = "Registry type (cnvrg, dockerhub, gcr, acr, ecr, ...)"
+REGISTRY_HELP_SLUG = "Registry slug"
+REGISTRY_HELP_TITLE = "Registry title"
+REGISTRY_HELP_USERNAME = "Registry username for private registries"
+REGISTRY_HELP_PASSWORD = "Registry password for private registries"
+
+REGISTRY_PROMPT_URL = "Please enter registry url"
+REGISTRY_PROMPT_TITLE = "Please enter registry tag"
+
+REGISTRY_CREATE_SUCCESS = "Successfully created registry {0}"
