@@ -1,5 +1,6 @@
 # GLOBAL
 NO_FILE = "File not found"
+NO_DIR = "Directory not found"
 
 # VALIDATIONS
 FAULTY_KEY = 'Faulty key {0}'
@@ -8,6 +9,7 @@ MISSING_REQUIRED_VALUE = 'Missing required value {0}'
 
 INVALID_URL = 'URL is invalid'
 INVALID_EMAIL = 'Email is invalid'
+INVALID_CREDENTIALS = "Could not login using the provided credentials, please check your credentials and try again"
 
 # ORGANIZATION
 ORGANIZATION_DOESNT_EXIST = "The requested organization does not exist"
@@ -32,7 +34,21 @@ CONTEXT_SCOPE_BAD_SCOPE = "Cannot connect to {0}, please provide a slug"
 CONTEXT_SCOPE_BAD_DEPENDENCIES = "Cannot connect to {0} since no {1} is present"
 
 # IMAGE
+IMAGE_BAD_TAG = "Image tag is invalid"
+IMAGE_BAD_NAME = "Image name is invalid"
+IMAGE_BAD_LOGO = "Image logo is not supported"
+IMAGE_BAD_REGISTRY = "Image registry must be a string"
 IMAGE_GET_FAULTY_PARAMS = "Cannot get image. Please provide a slug or image name and tag (all strings)."
+IMAGE_CUSTOM_DOCKERFILE_REQUIRED = "Custom image requires a dockerfile"
+
+# REGISTRY
+REGISTRY_BAD_URL = "Registry url must be a string"
+REGISTRY_BAD_URL_FORMAT = "Bad registry url format (example: good-url.io)"
+REGISTRY_BAD_TYPE = "Registry type is not supported"
+REGISTRY_BAD_TITLE = "Registry title must be a string"
+REGISTRY_BAD_USERNAME = "Registry username must be a string"
+REGISTRY_BAD_PASSWORD = "Registry password must be a string"
+REGISTRY_USERNAME_AND_PASSWORD = "Please provide both username and password or neither"
 
 # VOLUME
 VOLUME_GET_FAULTY_PARAMS = "Cannot get volume. Please provide a slug or volume name."
@@ -78,6 +94,7 @@ SPARK_DRIVER_GET_FAULTY_SLUG = "Cannot get spark driver with empty or a non stri
 
 # CLUSTER
 CLUSTER_GET_FAULTY_SLUG = 'Cannot get cluster with empty or a non string slug'
+CLUSTER_ONE_TYPE = 'The given arguments: {} and {} cannot be sent together'
 
 # TEMPLATES
 TEMPLATE_GET_FAULTY_SLUG = "Cannot get template with empty slug or a non string slug"
@@ -129,6 +146,11 @@ FILE_TOTAL = "File total is mandatory for azure callback. Please provide a mutab
 NOT_SUPPORTED = "{} are not supported"
 SECRETS_NOT_SUPPORTED = "{} are not supported, use update_secret or delete_secret methods"
 
+# GIT
+CANT_USE_BOTH_SSH_AND_TOKEN = "Can't use both SSH and Token for authentication with git"
+INVALID_SSH_KEY_TYPE = "SSH Key Type needs to be plain/file"
+CANT_READ_SSH_KEY_FILE = "Can't read SSH key file"
+
 # CLI - CONFIG FILE
 CONFIG_FILE_MISSING = "Config file doesn't exist."
 LOCAL_CONFIG_MISSING_DATA_OWNER_SLUG = "Cannot preform operation. Couldn't find project or dataset name" \
@@ -143,6 +165,9 @@ DIRECTORY_ALREADY_LINKED = "Directory is already linked to {0}"
 NOT_A_GIT_PROJECT = "Project {0} is not a git project"
 PROJECT_NOT_EXIST = "Project {0} is not a cnvrg project"
 
+# CLI - MEMBERS
+MEMBER_NOT_VALID_ROLE = "{0} is not a valid role, valid roles are: admin, manager, member, reviewer"
+
 # CLI - SSH
 SSH_FAILED_TO_START = "Failed to start ssh. Ssh status: {0}"
 SSH_FAILED_GET_REQUIRED_PARAMS = "Failed to get required ssh params. Ssh status: {0}"
