@@ -1,7 +1,8 @@
 import os
+
 import requests
 
-from cnvrgv2.config import CONFIG_VERSION, Config
+from cnvrgv2.config import Config, CONFIG_VERSION
 from cnvrgv2.config import error_messages, routes
 from cnvrgv2.errors import CnvrgArgumentsError, CnvrgError, CnvrgHttpError
 from cnvrgv2.modules.users.users_client import UsersClient
@@ -17,6 +18,10 @@ class SCOPE:
         "key": "image",
         "dependencies": ["organization", "user"]
     }
+    REGISTRY = {
+        "key": "registry",
+        "dependencies": ["organization", "user"]
+    }
     VOLUME = {
         "key": "volume",
         "dependencies": ["project", "organization", "user"]
@@ -25,6 +30,10 @@ class SCOPE:
         "key": "dataset",
         "dependencies": ["organization", "user"]
     }
+    MEMBER = {
+        "key": "member",
+        "dependencies": ["organization"]
+    }
     LIBRARY = {
         "key": "library",
         "dependencies": ["organization", "user"]
@@ -54,7 +63,7 @@ class SCOPE:
         "dependencies": ["project", "organization", "user"]
     }
     WORKSPACE = {
-        "key": "workspace",
+        "key": "notebooksession",
         "dependencies": ["project", "organization", "user"]
     }
     WEBAPP = {
