@@ -8,13 +8,14 @@ from cnvrgv2.utils.url_utils import urljoin
 
 
 class FileCompare(LocalFilesHandler):
-    def __init__(self, data_owner, files, override=False, num_workers=40, chunk_size=1000, queue_size=5000):
+    def __init__(self, data_owner, paths, metadata, override=False, num_workers=40, chunk_size=1000, queue_size=5000):
         """
         Multithreaded file compare for cnvrg datasets - used to compare between files that should be uploaded
         so we can mark conflicts
 
         @param data_owner: Cnvrg dataset / project object
-        @param files: list of files to upload
+        @param paths: [Generator] that lists paths to upload
+        @param metadata: [Dict] The metadata on the uploaded files (total files, file size..)
         @param override: Boolean stating whether or not we should re-upload even if the file already exists
         @param num_workers: Number of threads to use for concurrent file upload
         @param chunk_size: File meta chunk size to fetch from the server
@@ -22,7 +23,8 @@ class FileCompare(LocalFilesHandler):
         """
         super().__init__(
             data_owner,
-            files=files,
+            paths=paths,
+            metadata=metadata,
             override=override,
             num_workers=num_workers,
             chunk_size=chunk_size,
