@@ -23,12 +23,17 @@ from cnvrgv2.modules.file import File
 from cnvrgv2.modules.folder import Folder
 from cnvrgv2.proxy import HTTP
 from cnvrgv2.utils.api_list_generator import api_list_generator
+from cnvrgv2.utils.path_generators import metadata_generator
 from cnvrgv2.utils.converters import convert_bytes
 from cnvrgv2.utils.filter_utils import list_to_multiple_conditions, Operators
-from cnvrgv2.utils.storage_utils import (cnvrgignore_exists, create_cnvrgignore, create_dir_if_not_exists,
-                                         filter_by_mimetypes, get_files_and_dirs_recursive)
+from cnvrgv2.utils.storage_utils import (
+    cnvrgignore_exists,
+    create_cnvrgignore,
+    build_cnvrgignore_spec,
+    create_dir_if_not_exists,
+    get_files_and_dirs_recursive
+)
 from cnvrgv2.utils.url_utils import urljoin
-from cnvrgv2.utils.validators import validate_directory_name
 
 
 class DataOwner(DynamicAttributes):
@@ -38,31 +43,39 @@ class DataOwner(DynamicAttributes):
         # Data attributes
         self._config = Config()
         self._working_dir = None
-        self._storage_meta = None
-        self._storage_meta_update_time = None
         self._local_commit = None
         self.query = None
 
-    @property
-    def storage_meta(self):
+    def storage_meta_refresh_function(self):
         """
-        Retrieve the storage meta of the data owner
-        @return: storage meta in a dict
+        Creates a function that returns an object containing credentials for the storage client
+        @return: function for getting credentials for storage client
         """
         # Calculate minutes diff from last update. If over 5 minutes - update storage meta.
-        minutes_diff = 0
-        if self._storage_meta_update_time is not None:
-            minutes_diff = (datetime.now() - self._storage_meta_update_time).total_seconds() / 60
-        if self._storage_meta is None or minutes_diff > 5:
-            response = self._proxy.call_api(
-                route=urljoin(self._route, "storage_client"),
-                http_method=HTTP.GET
-            )
-            storage_meta = response.meta["storage"]
-            self._storage_meta = storage_meta
-            self._storage_meta_update_time = datetime.now()
+        storage_meta_update_time = None
+        storage_meta = None
+        storage_client_url = urljoin(self._route, "storage_client")
+        proxy = self._proxy
 
-        return self._storage_meta
+        def refresher():
+            nonlocal storage_meta_update_time
+            nonlocal storage_meta
+            minutes_diff = 0
+
+            if storage_meta_update_time is not None:
+                minutes_diff = (datetime.now() - storage_meta_update_time).total_seconds() / 60
+
+            if storage_meta is None or minutes_diff > 5:
+                response = proxy.call_api(
+                    route=storage_client_url,
+                    http_method=HTTP.GET
+                )
+                storage_meta = response.meta["storage"]
+                storage_meta_update_time = datetime.now()
+
+            return storage_meta
+
+        return refresher
 
     @abc.abstractmethod
     def _validate_config_ownership(self):
@@ -173,7 +186,6 @@ class DataOwner(DynamicAttributes):
     def put_files(
         self,
         paths,
-        pattern="*",
         message="",
         job_slug=None,
         blank=False,
@@ -187,8 +199,7 @@ class DataOwner(DynamicAttributes):
         """
         Uploads the files and folders given.
         If a folder is given all the relevant files in that folder (that confirms to the regex) will be uploaded.
-        @param paths: List of file/folder paths
-        @param pattern: String defining the filename pattern
+        @param paths: List of paths or unix-style wildcards
         @param message: String defining the commit message
         @param job_slug: Slug of a job to upload the files to
         @param blank: Start from a blank state or from a previous commit
@@ -201,72 +212,37 @@ class DataOwner(DynamicAttributes):
         @return: string - The Commit sha1 that was created
         """
 
-        filters = []
-        if tag_images:
-            filters = ['image']
-
-        paths_to_upload = paths
+        last_commit = self.local_commit
+        if job_slug is not None:
+            # Ugly patch, decided on 12/07/2022 by Elad
+            # For experiments, parent commit should be last commit and not start commit
+            if type(self).__name__ == 'Experiment':
+                last_commit = self.last_commit
+            elif last_commit is None and self.start_commit is not None:
+                last_commit = self.start_commit["sha1"]
 
+        # Set relevant variables
+        filters = ['image'] if tag_images else []
+        paths_to_upload = paths if isinstance(paths, list) else [paths]
         if git_diff:
             paths_to_upload += self._handle_git_files()
 
-        full_paths = self._get_full_paths(paths_to_upload, filters, pattern)
-        unique_full_paths = list(set(full_paths) - {"./", ".", "/", "//"})
+        # Parses the cnvrgignore and returns a gitignore-like filter object
+        ignore_spec = build_cnvrgignore_spec(self._config.root)
+        # Get the temp folder path
+        temp_folder_path = "{}/{}".format(self.working_dir, DataOwner.TMP_FOLDER_NAME)
 
-        if not unique_full_paths and not upload:
+        metadata, path_generator = metadata_generator(
+            paths=paths_to_upload,
+            mime_filters=filters,
+            ignore_spec=ignore_spec,
+            temp_folder=temp_folder_path
+        )
+
+        if metadata["total_files"] == 0:
             return
 
-        last_commit = self.local_commit
-
-        if job_slug is not None and last_commit is None and self.start_commit is not None:
-            last_commit = self.start_commit["sha1"]
-
-        unique_full_paths = self._filter_deleted_files(unique_full_paths)
-        validate_directory_name(unique_full_paths)
-
-        if not unique_full_paths:
-            return
-
-        return self._upload_files(message, blank, last_commit, job_slug, force, unique_full_paths, override,
-                                  progress_bar_enabled, tag_images, upload)
-
-    def _filter_deleted_files(self, unique_full_paths):
-        result = []
-        tmp_folder = "{}/{}".format(self.working_dir, DataOwner.TMP_FOLDER_NAME)
-
-        # This function should run only if tmp folder exist (sync/download)
-        if not os.path.exists(tmp_folder):
-            return unique_full_paths
-
-        for up in unique_full_paths:
-            deleted_file = "{}/{}.deleted".format(tmp_folder, up)
-            if not os.path.exists(deleted_file):
-                result.append(up)
-
-        # Make sure to filter out all paths that are under deleted folders
-        deleted_folders = get_files_and_dirs_recursive(root_dir=tmp_folder, regex=".*deleted/", force=True)
-        for deleted_folder in deleted_folders:
-            # Prepare a regex that matches all paths in the regular dir, that are under a dir marked to be deleted
-            # in the tmp folder
-            matching_path = deleted_folder.replace(".tmp/", "").replace(".deleted", "")
-            regex = re.compile("^(?!{})".format(matching_path))
-            result = [path for path in result if regex.match(path)]
-
-        return result
-
-    def _handle_git_files(self):
-        return list(filter(None, self.get_git_diff()))  # Clean from falsy values
-
-    def get_git_diff(self):
-        """
-        collects file names from git diff output
-        @return: list of file names from git diff command
-        """
-        command = "git diff --name-only"
-        return os.popen(command).read().strip().split("\n")
-
-    def _upload_files(self, message, blank, last_commit, job_slug, force, paths, override, progress_bar_enabled,
-                      tag_images, upload):
+        # Create a new commit
         commit_sha1 = self._start_commit(
             message=message,
             blank=blank,
@@ -275,8 +251,13 @@ class DataOwner(DynamicAttributes):
             force=force
         )
 
-        uploader = self._get_file_uploader(paths, commit_sha1, override, progress_bar_enabled)
-
+        uploader = self._get_file_uploader(
+            paths=path_generator,
+            commit=commit_sha1,
+            metadata=metadata,
+            override=override,
+            progress_bar_enabled=progress_bar_enabled
+        )
         while uploader.in_progress:
             time.sleep(0.1)
 
@@ -292,58 +273,42 @@ class DataOwner(DynamicAttributes):
 
         # Pass with_commit_compare to end_commit: the server will delete the commit if it is identical to the previous
         # One (in the case where nothing has actually been updated to the server)
-        with_commit_compare = not override
-        commit = self._end_commit(commit_sha1=commit_sha1, tag_images=tag_images,
-                                  with_commit_compare=with_commit_compare)
+        commit = self._end_commit(
+            commit_sha1=commit_sha1,
+            tag_images=tag_images,
+            with_commit_compare=not override
+        )
+
         # Commit will be null if the commit has been deleted
         # In the case nothing has actually been updated to the server, return last_commit
         return commit if commit else self.last_commit
 
-    def _get_file_uploader(self, paths, commit_sha1, override, progress_bar_enabled):
+    def _get_file_uploader(self, paths, commit, metadata, override, progress_bar_enabled):
         # this is required for mocking. please don't delete the wrapping function
         return FileUploader(
-            self,
-            paths,
-            commit=commit_sha1,
+            data_owner=self,
+            paths=paths,
+            commit=commit,
+            metadata=metadata,
             override=override,
             progress_bar_enabled=progress_bar_enabled
         )
 
+    def _handle_git_files(self):
+        return list(filter(None, self.get_git_diff()))  # Clean from falsy values
+
+    def get_git_diff(self):
+        """
+        collects file names from git diff output
+        @return: list of file names from git diff command
+        """
+        command = "git diff --name-only"
+        return os.popen(command).read().strip().split("\n")
+
     def _get_remote_file_deleter(self, commit_sha1):
         # this is required for mocking. please don't delete the wrapping function
         return RemoteFileDeleter(self, commit=commit_sha1)
 
-    def _get_full_paths(self, paths_to_upload, filters, pattern):
-        result = []
-        for path in paths_to_upload:
-            is_dir = os.path.isdir(path)
-            is_file = os.path.isfile(path)
-
-            if is_dir:
-                result += get_files_and_dirs_recursive(
-                    root_dir=path,
-                    regex=pattern,
-                    project_root=self._config.root,
-                    filters=filters)
-                continue
-
-            if is_file and filter_by_mimetypes(filters, path):
-                result.append(path)
-                continue
-
-            # path sent might be a regex
-            files_by_regex = get_files_and_dirs_recursive(
-                root_dir=".",
-                regex=path,
-                filters=filters)
-
-            if files_by_regex:
-                result += files_by_regex
-                continue
-
-            print("{} does not exists skipping it".format(path))
-        return result
-
     def remove_files(self, paths, message="", progress_bar_enabled=False):
         """
         Removes the given files remotely
@@ -398,13 +363,15 @@ class DataOwner(DynamicAttributes):
             payload=data
         ).meta
 
-    def clone(self, progress_bar_enabled=False, override=False, commit=None, use_cached=False):
+    def clone(self, progress_bar_enabled=False, override=False, commit=None, use_cached=False, threads=40,
+              query_slug=None):
         """
         Clones the remote project / dataset
         @param progress_bar_enabled: Boolean indicating whenever or not to print a progress bar. In use of the cli
         @param override: Boolean stating whether we should re-clone even if the project / dataset already cloned
         @param commit: [String] sha1 of the commit to clone
         @param use_cached: Boolean stating whether to use nfs cache link or not
+        @param threads: number of threads that will be used in order to clone the project
         @return: None
         """
         self.reload()
@@ -421,12 +388,22 @@ class DataOwner(DynamicAttributes):
                 shutil.rmtree(self.slug + '/' + CONFIG_FOLDER_NAME)
 
         if commit and commit.lower() != 'latest':
+            # self.last_commit should be a value returned from the server,
+            # and no value should be manually assigned to it.
+            # this is a workaround for cloning a specific commit:
+            # because FileDownloader uses self.last_commit instead of receiving commit as an arg
+            # todo : pass commit to FileDownloader
+
             self.last_commit = commit
 
         old_working_dir = self.working_dir
         self.working_dir = "{}/{}".format(old_working_dir, self.slug)
 
-        downloader = FileDownloader(self, progress_bar_enabled=progress_bar_enabled, use_cached=use_cached)
+        # Will download files from self.last_commit.
+        # In the case of cloning a specific commit, last_commit is actually that specific commit assigned previously
+
+        downloader = FileDownloader(self, progress_bar_enabled=progress_bar_enabled, use_cached=use_cached,
+                                    num_workers=threads, query_slug=query_slug)
 
         while downloader.in_progress:
             time.sleep(1)
@@ -436,22 +413,28 @@ class DataOwner(DynamicAttributes):
                 os.rmdir(self.slug)
             raise CnvrgError(downloader.errors.args)
 
+        # In the case of cloning a specific commit, last_commit is that specific commit
+        # and not the actual data_owner last_commit
         self.local_commit = self.last_commit
         self.save_config(local_config_path=self.working_dir + '/' + CONFIG_FOLDER_NAME)
 
+        # Reload will reset self.last_commit to the actual data_owner last_commit in case it has been changed previously
         self.reload()
         self.working_dir = old_working_dir
 
         if not cnvrgignore_exists(self.slug):
             create_cnvrgignore(self.slug)
 
-    def upload(self, sync=False, job_slug=None, progress_bar_enabled=False, git_diff=False):
+    def upload(self, sync=False, job_slug=None, progress_bar_enabled=False, git_diff=False, message="",
+               output_dir=None):
         """
         Uploads files to remote project / dataset
         @param sync: Boolean gives info if the put files comes from sync or not
         @param job_slug: Slug of a job to upload the files to
         @param progress_bar_enabled: Boolean indicating whenever or not to print a progress bar. In use of the cli
         @param git_diff: upload only files from git diff output
+        @param message: String defining the commit message
+        @param output_dir: String will only upload the files in the output_dir specified
         @return: None
         """
 
@@ -460,15 +443,17 @@ class DataOwner(DynamicAttributes):
         if not self._validate_config_ownership():
             raise CnvrgFileError(error_messages.CONFIG_YAML_NOT_FOUND)
 
+        working_dir = "{0}/{1}".format(self._config.root, output_dir) if output_dir else self._config.root
         old_working_dir = os.getcwd()
         os.chdir(self._config.root)
 
         new_commit_sha1 = self.put_files(
-            [self._config.root],
+            [working_dir],
             upload=True,
             job_slug=job_slug,
             progress_bar_enabled=progress_bar_enabled,
-            git_diff=git_diff
+            git_diff=git_diff,
+            message=message
         )
 
         if sync:
@@ -486,7 +471,6 @@ class DataOwner(DynamicAttributes):
         @param commit_sha1: Sha1 of a specific commit to download
         @return: None
         """
-
         # We want to make sure we are in a project/dataset folder in order to continue with the action
         self.reload()
         if not self._validate_config_ownership():
@@ -536,17 +520,20 @@ class DataOwner(DynamicAttributes):
 
         os.chdir(context_working_dir)
 
-    def sync(self, job_slug=None, git_diff=False, progress_bar_enabled=False):
+    def sync(self, job_slug=None, git_diff=False, progress_bar_enabled=False, message='', output_dir=None):
         """
         Sync local project / dataset to remote
         @param job_slug: Slug of a job to upload the files to
         @param git_diff: upload only files from git diff output
         @param progress_bar_enabled: Boolean indicating whenever or not to print a progress bar. In use of the cli
+        @param message: String defining the commit message
+        @param output_dir: String will only sync the files in the output_dir specified
         @return: None
         """
         try:
             self.download(sync=True, progress_bar_enabled=progress_bar_enabled)
-            self.upload(sync=True, progress_bar_enabled=progress_bar_enabled, job_slug=job_slug, git_diff=git_diff)
+            self.upload(sync=True, progress_bar_enabled=progress_bar_enabled, job_slug=job_slug, git_diff=git_diff,
+                        message=message, output_dir=output_dir)
         finally:
             # make sure the tmp folder used by download and upload will be deleted
             if os.path.exists(DataOwner.TMP_FOLDER_NAME):
@@ -597,11 +584,10 @@ class DataOwner(DynamicAttributes):
         """
         tmp_folder = "{}/{}".format(self.working_dir, DataOwner.TMP_FOLDER_NAME)
         try:
-            fullpaths = get_files_and_dirs_recursive(root_dir='.')
-            unique_fullpaths = list(set(fullpaths) - {"./", ".", "/", "//"})
+            metadata, path_generator = metadata_generator(['.'])
 
-            if unique_fullpaths:
-                compare = FileCompare(self, unique_fullpaths)
+            if metadata["total_files"] > 0:
+                compare = FileCompare(self, paths=path_generator, metadata=metadata)
                 while compare.in_progress:
                     time.sleep(1)
 
