@@ -441,3 +441,10 @@ class Endpoint(WorkflowInstanceBase):
 
         print(res_content)
         return res_content
+
+    def restart(self):
+        """
+        Override restart from workflows_base to remove functionality.
+        restart() is only relevant for webapps
+        """
+        raise AttributeError("'Endpoint' object has no attribute 'restart'")
\ No newline at end of file
