@@ -36,12 +36,11 @@ def validate_username(username):
     return re.search(regex, username) is not None
 
 
-def validate_directory_name(paths):
+def validate_directory_name(path):
     regex = r"^[a-zA-Z0-9_.()'!\/-]+$"
-    for path in paths:
-        is_dir = os.path.isdir(path)
-        if is_dir and not re.match(regex, path):
-            raise CnvrgArgumentsError(error_messages.NOT_A_VALID_DIRECTORY_NAME.format(path))
+    is_dir = os.path.isdir(path)
+    if is_dir and not re.match(regex, path):
+        raise CnvrgArgumentsError(error_messages.NOT_A_VALID_DIRECTORY_NAME.format(path))
 
 
 def validate_types_in_list(input_list, input_type):
